@@ -144,7 +144,7 @@ import Data.Traversable
 import Control.Applicative
 #endif
 import Control.Parallel
-import Control.DeepSeq
+import Control.DeepSeq (NFData(rnf))
 import Control.Monad
 
 import qualified Control.Seq
@@ -474,6 +474,8 @@ parListN n strat = evalListN n (rparWith strat)
 
 -- | Evaluate the nth element of a list (if there is such) according to
 -- the given strategy.
+-- This nth is 0-based. For example, @[1, 2, 3, 4, 5] `using` evalListNth 4 rseq@
+-- will eval @5@, not @4@.
 -- The spine of the list up to the nth element is evaluated as a side effect.
 evalListNth :: Int -> Strategy a -> Strategy [a]
 evalListNth n strat = evalListSplitAt n r0 (evalListN 1 strat)
@@ -862,7 +864,7 @@ presented in the paper
   /Seq no More: Better Strategies for Parallel Haskell/
   <http://community.haskell.org/~simonmar/papers/strategies.pdf>
 
-The major differenes in the API are:
+The major differences in the API are:
 
  * The addition of Sequential strategies ("Control.Seq") as
    a composable means for specifying sequential evaluation.
